// muzflash.vert
// put mzflash.x in same folder/directory

#define UWrapNum   1.0
#define VWrapNum   1.0
//#define lineSize   2.0
#define lineSize   4.0
//#define lineLength 3.0
#define lineLength 0.5
#define timeLength 0.25

uniform float time;
uniform vec3  cameraPosition;
uniform vec3   modelPosition;
uniform vec3   modelDirection;
uniform vec3   modelUpper;

varying vec2  texCoord;

void main(void){
	if(time < 0.0 || time > timeLength) {
		gl_Position = 0.0;
		texCoord = 0.0;
		return;
	}
	vec4  position = vec4(0.0, 0.0, 0.0, 1.0);
	vec3 direction = vec3(0.0, 0.0, -1.0); // vec

	vec3 eyevec    = normalize( modelPosition - cameraPosition);

	vec3 modelRight = normalize(cross(modelDirection, modelUpper));
	modelUpper = normalize(cross(modelRight, modelDirection));
	mat3 worldToLocal = inverse(mat3(modelRight, modelUpper, -modelDirection));

	vec3 side      = normalize(cross(eyevec, modelDirection));
	side     = worldToLocal * side;

	float w = pow(      time/timeLength,  2.0);

	side *= lineSize/2.0/2.0;
	side *= w;

	direction *=  lineLength * 5.0 * (1.0-w);

	if(gl_Vertex.z > 0.0){
		texCoord.s = 0.0; 
		position += float4(direction, 0.0);
	}else{
		texCoord.s = 1.0 * UWrapNum;
	}

	if(gl_Vertex.x > 0.0){
		texCoord.t = 0.0;
		position += vec4( side, 0.0);
	}else{
		texCoord.t = 1.0 * VWrapNum; 
		position -= vec4( side, 0.0);
	}

	gl_Position =                                position;
	gl_Position = gl_ModelViewMatrix           * gl_Position;
	gl_Position = gl_ProjectionMatrix          * gl_Position;
}
